Imported from archive.
[mudpy.git] / mudpy.py
index 3650f89..9f5cd1d 100644 (file)
--- a/mudpy.py
+++ b/mudpy.py
@@ -559,7 +559,7 @@ class User:
                for old_user in universe.userlist:
 
                        # the name is the same but it's not us
-                       if old_user.account.get("name") == self.account.get("name") and old_user is not self:
+                       if hasattr(old_user, "account") and old_user.account.get("name") == self.account.get("name") and old_user is not self:
 
                                # make a note of it
                                log("User " + self.account.get("name") + " reconnected--closing old connection to " + old_user.address + ".", 2)
@@ -651,8 +651,8 @@ class User:
                        # find and replace macros in the output
                        output = replace_macros(self, output)
 
-                       # wrap the text at 80 characters
-                       output = wrap_ansi_text(output, 80)
+                       # wrap the text at 79 characters
+                       output = wrap_ansi_text(output, 79)
 
                        # tack the terminator back on
                        if terminate: output += self.terminator